@@ -3,6 +3,7 @@ import json
 import jwt
 from warnings import warn
 
+OPTIONS = 'OPTIONS'
 
 class JWTPlugin:
     def __init__(self, secret: str, verify: bool = True, mapper: dict = None):
@@ -46,3 +47,18 @@ class ApiKeyAuthPlugin:
             response.content_type = 'application/json'
             return json.dumps({'error': 'invalid API key'})
         return wrapped_handler
+
+
+# from https://stackoverflow.com/questions/17262170/bottle-py-enabling-cors-for-jquery-ajax-requests
+class CorsPlugin:
+    def __init(self, origins: str = '*'):
+        self._origins = origins
+
+    def __call__(self, handler):
+        def wrapped_handler(*args, **kwargs):
+            response.headers['Access-Control-Allow-Origin'] = self._origins
+            response.headers['Access-Control-Allow-Methods'] = 'GET, POST, PUT, OPTIONS'
+            response.headers['Access-Control-Allow-Headers'] = 'Origin, Accept, Content-Type, X-Requested-With, X-CSRF-Token'
+            if request.method != OPTIONS:
+                return handler(*args, **kwargs)
+        return wrapped_handler
